Non-blocking pipeline plug that forwards events to an async persistence writer.
Options:
:writer(required): writer pid started viaASM.Extensions.Persistence.start_writer/1:on_failure(optional)::drop(default) or:halt
Non-blocking pipeline plug that forwards events to an async persistence writer.
Options:
:writer (required): writer pid started via ASM.Extensions.Persistence.start_writer/1:on_failure (optional): :drop (default) or :halt