Assistant-authored message composed of one or more content blocks.
Summary
Types
@type t() :: %ASM.Message.Assistant{ content: [ASM.Content.t()], metadata: map(), model: String.t() | nil }
Assistant-authored message composed of one or more content blocks.
@type t() :: %ASM.Message.Assistant{ content: [ASM.Content.t()], metadata: map(), model: String.t() | nil }