User-authored message composed of one or more content blocks.
Summary
Types
@type t() :: %ASM.Message.User{content: [ASM.Content.t()]}
User-authored message composed of one or more content blocks.
@type t() :: %ASM.Message.User{content: [ASM.Content.t()]}