AgentSessionManager.Adapters.EctoSessionStore.Migration (AgentSessionManager v0.8.0)

Copy Markdown View Source

Provides migration functions for the EctoSessionStore adapter.

This migration is canonical for the unreleased 0.8.0 persistence schema and creates all required tables, columns, and indexes in one step.

Usage

Create a migration in your application:

defmodule MyApp.Repo.Migrations.AddAgentSessionManager do
  use Ecto.Migration

  def up do
    AgentSessionManager.Adapters.EctoSessionStore.Migration.up()
  end

  def down do
    AgentSessionManager.Adapters.EctoSessionStore.Migration.down()
  end
end

Summary

Functions

Drops all tables created by up/0.

Creates all tables and indexes required by the EctoSessionStore.

Functions

down()

Drops all tables created by up/0.

up()

Creates all tables and indexes required by the EctoSessionStore.