AgentSessionManager.Rendering.Sinks.FileSink (AgentSessionManager v0.8.0)

Copy Markdown View Source

A sink that writes rendered output to a log file with ANSI codes stripped.

Options

  • :path — File path to write to. Required unless :io is given.
  • :io — Pre-opened IO device to write to. When provided, :path is ignored and the device will not be closed by close/1.