Discovery metadata and strict derivation helpers for the optional Cursor-native ASM extension namespace.
Cursor's SDK lane is enabled once cursor_cli_sdk is present. Core-lane
Cursor execution remains owned by CliSubprocessCore.ProviderProfiles.Cursor.
Summary
Functions
Derives CursorCliSdk.Options from strict common ASM options.
Functions
@spec available?() :: boolean()
Derives CursorCliSdk.Options from strict common ASM options.
Cursor-native controls such as :mode, :sandbox, :approve_mcps,
worktree flags, plugin directories, and headers belong in :native_overrides.
@spec extension() :: ASM.Extensions.ProviderSDK.Extension.t()
@spec native_capabilities() :: [atom()]
@spec native_surface_modules() :: [module()]
@spec sdk_app() :: atom()
@spec sdk_module() :: module()