Convenience supervisor for StreamSession infrastructure.
Add this to your application supervision tree to enable supervised task and adapter lifecycle management for StreamSession:
children = [
AgentSessionManager.StreamSession.Supervisor,
# ... other children
]
Supervisor.start_link(children, strategy: :one_for_one)
Summary
Functions
Returns a specification to start this module under a supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.